Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(68)

Unified Diff: google_apis/drive/drive_common_callbacks.h

Issue 881403003: Rename gdata_errorcode.h to drive_api_error_codes.h (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fix typos in BUILD.gn Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: google_apis/drive/drive_common_callbacks.h
diff --git a/google_apis/drive/drive_common_callbacks.h b/google_apis/drive/drive_common_callbacks.h
index db2a7aee9b1ac5618ae6ca90cf2ec910a58d4d7f..087903333c71370baedf795119a3322dd8096698 100644
--- a/google_apis/drive/drive_common_callbacks.h
+++ b/google_apis/drive/drive_common_callbacks.h
@@ -16,27 +16,27 @@ class AboutResource;
class AppList;
// Callback used for getting AboutResource.
-typedef base::Callback<void(GDataErrorCode error,
+typedef base::Callback<void(DriveApiErrorCode error,
scoped_ptr<AboutResource> about_resource)>
AboutResourceCallback;
// Callback used for getting ShareUrl.
-typedef base::Callback<void(GDataErrorCode error,
+typedef base::Callback<void(DriveApiErrorCode error,
const GURL& share_url)> GetShareUrlCallback;
// Callback used for getting AppList.
-typedef base::Callback<void(GDataErrorCode error,
+typedef base::Callback<void(DriveApiErrorCode error,
scoped_ptr<AppList> app_list)> AppListCallback;
// Callback used for authorizing an app. |open_url| is used to open the target
// file with the authorized app.
-typedef base::Callback<void(GDataErrorCode error,
+typedef base::Callback<void(DriveApiErrorCode error,
const GURL& open_url)>
AuthorizeAppCallback;
// Closure for canceling a certain request. Each request-issuing method returns
// this type of closure. If it is called during the request is in-flight, the
// callback passed with the request is invoked with GDATA_CANCELLED. If the
// request is already finished, nothing happens.
typedef base::Closure CancelCallback;
@@ -16,27 +16,27 @@ class AboutResource;
// Closure for canceling a certain request. Each request-issuing method returns
// this type of closure. If it is called during the request is in-flight, the
-// callback passed with the request is invoked with GDATA_CANCELLED. If the
+// callback passed with the request is invoked with DRIVE_CANCELLED. If the
// request is already finished, nothing happens.
typedef base::Closure CancelCallback;

Powered by Google App Engine
This is Rietveld 408576698